@@ -11,7 +11,6 @@ class MyReportTest(HTSQLReport):
         delimiter = ";"
         connexion = "sqlite:htsql_demo.sqlite"
         name = "myReport"
-        arguments = ['name']
 
 class TestReport(TestCase):
     def setUp(self):
@@ -55,6 +54,27 @@ class MyDjangoReportTest(DjangoReport):
     queryset = ReportTracking.objects.all()
     delimiter = ";"
     name = "my django report"
+<<<<<<< HEAD
+
+    def get_row(self, line):
+        return [line.report_name, line.status]
+
+class MyDjangoReportWithHeaderTest(MyDjangoReportTest):
+    name = "my django report"
+    header = ['report name', 'status']
+
+
+class MyDjangoReportTest(DjangoReport):
+    encoding = "latin-1"
+    delimiter = ";"
+    name = "my django report"
+
+    def get_row(self, line):
+        return [line.report_name, line.status]
+
+    def get_queryset(self, **parameters):
+        return ReportTracking.objects.all()
+=======
     arguments = ['name']
 
     def get_row(self, line):
@@ -63,6 +83,7 @@ class MyDjangoReportTest(DjangoReport):
 class MyDjangoReportWithHeaderTest(MyDjangoReportTest):
     name = "my django report"
     header = ['report name', 'status']
+>>>>>>> ceeb21ce69d2f3d3bef14718f6ca022bb8a35e2c
 
 class DjangoReportTest(TestCase):
     def test_report(self):
